<template>
  <win-lg :title="setting.title" @close="close" :width="'800px'">
    <el-card class="box-card" shadow="never">
      <div class="filter-container" style="margin-bottom: 10px">
        <my-search ref="searchBar" :items="items" @search="filterForm"></my-search>
      </div>
      <!--列表-->
      <my-table-v2 ref="myTable" :filter="filterFrom" :table="table"/>
    </el-card>
    <edit v-if="editSetting.show" :setting="editSetting" @close="closeNode" @search="search"></edit>
  </win-lg>
</template>

<script>
import MyTableV2 from '@/components/myTable/myTableV2';
import winLg from '@/components/win/win-lg'
import SettingIplatform from '@/utils/settingIplatform';
import items from './items';
import edit from './edit'
import {del, updStatus} from "@/api/projectConfig/stageNode";

export default {
  name: 'nodeConfig',
  components: {MyTableV2, winLg, edit},
  props: {
    // setting 中须至少包含控制dialog显示或隐藏的属性,其余属性可拓展
    // 将添加/修改的大量数据及逻辑从列表页面中分离出来,避免列表页面代码过多,审查困难
    // 若此页面须回传数据至父页面,可在引用组件时添加事件,本页面使用this.$emit('事件名',参数1,参数2...)回传数据
    setting: {
      type: Object,
      default: () => {
      }
    }
  },
  data() {
    return {
      // 搜索条件
      items: items,
      filterFrom: {
        nodeName: '',
        status: '1',
      },
      //新增编辑
      editSetting: {
        title: '',
        id: '',
        show: false,
      },
      // 表格数据
      table: {
        showIndex: true, // 是否显示序号
        expand: false, // 是否显示详情数据
        url: SettingIplatform.apiBaseURL + '/pc/p/temp/stage/node/list?stageId='+this.setting.stageId, // 请求地址
        // 工具条
        tools: {
          columnsCtrl: {
            // 列控制按钮
            show: false,
          },
          generalExport: {
            // 通用导出按钮
            show: false,
          },
          // 自定义工具条按钮
          custom: [
            {
              name: '新增',
              click: () => {
                this.showAdd(null);
              },
            },
          ],
        },
        // 列信息
        columns: [
          {title: '节点名称', field: 'nodeName', align: 'center'},
          {title: '顺序号', field: 'sort', align: 'center'},
          {title: '说明', field: 'remark', align: 'center'},
          {
            field: 'status',
            title: '状态',
            align: 'center',
            width: 80,
            switch: (row) => {
              return {
                value: row.status === 1, // 开
                label: row.status === 1 ? '启用' : '禁用', // 开的描述
                click: () => {
                  // 点击事件
                  this.updState(row);
                },
              };
            },
          },
        ],
        // 操作信息
        operation: {
          show: true, // 显示操作列
          width: '200', // 列宽
          attr: [
            {
              title: '编辑',
              events: (row) => {
                this.showAdd(row.id);
              },
            },
            {
              title: '删除',
              events: (row) => {
                this.handleDelete(row);
              },
            },
          ],
        },
        paging: {
          show: true, // 显示分页
          // 分页信息
          page: {
            small: false,
            pageNum: 1,
            pageSize: 10,
            total: 0,
          },
        },
      },
    };
  },
  mounted() {
  },
  methods: {
    close() {
      this.$emit('close')
    },
    closeNode() {
      this.editSetting.show = false
      this.$emit('search')
    },
    // 查询table列表
    search(pageNum) {
      if (pageNum != undefined) {
        this.$refs.myTable.search(pageNum);
      } else {
        this.$refs.myTable.search();
      }
    },
    filterForm(params) {
      this.filterFrom = Object.assign(this.filterFrom, params);
      this.search();
    },
    //添加、编辑
    showAdd(id) {
      let title = '添加';
      if (id != null) {
        title = '编辑';
      }
      this.editSetting.id = id||this.setting.id;
      this.editSetting.stageId = this.setting.stageId;
      this.editSetting.title = title;
      this.editSetting.show = true;
    },
    updState(row) {
      let text = row.status === 0 ? "启用" : "禁用";
      this.$modal.confirm('确认要' + text + '"' + row.nodeName + '"吗？').then(() => {
        let status = row.status === 1 ? 0 : 1
        updStatus({
          id: row.id,
          status
        }).then(res => {
          if (res) {
            row.status = row.status === 1 ? 0 : 1
            this.$modal.msgSuccess(text + "成功");
            this.search()
          }
        })
      })
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      this.$confirm('是否确认删除"' + row.nodeName + '"阶段？', {
        type: 'warning'
      }).then(() => {
        del({id:row.id}).then(res=>{
          this.$modal.msgSuccess( "删除成功");
          this.search()
        })
      })
    },
  },
};
</script>

<style scoped></style>
